
# Slot: date_modified

The date that the model was last modified

URI: [gocam:model__date_modified](https://w3id.org/gocam/model__date_modified)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Model](Model.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | dct:date |
